dataset <- function (phi_meanI, psi1, nSeason, SeasonB, SeasonA=nSeason - SeasonB, nSites, siteT, n_vis, phi_meanI, rC, rI, p) {

### 	The following parameters are given to the function:
### 	psi1      	= probability that a territory is occupied at t = 1
### 	nSeason	= total number of study seasons
### 	SeasonB	= number of seasons Before treatment
### 	nSites	= total number of sites
### 	siteT		= number of Treatment sites
### 	n_vis	    	= number of visits per site per season
### 	phi_meanC	= mean seasonal local survival Control 
### 	phi_meanI	= mean seasonal local survival Impact
###   sd.s	   	= sd of random normal variable introducing a Season effect
###		 		on local survival
###	rC		= territory colonization Before treatment
###	rI		= territory colonization After treatment
### 	p		= detection probability

###	Define matrix tocc (true territory occupancy state)
tocc <- matrix(rep(0, nSeason*nSites), ncol=nSeason)
tocc <- as.data.frame(tocc)
names(tocc) <- paste("s", 1:nSeason, sep="")

###	Define the matrix obsocc that contains the observations. The first j
###	columns will contain observed occupancy states for the first year on
###	the 1...j visits, the j+1 column will contain the observations of
###	the first visit in the second year, and so forth.
obsocc <- matrix(rep(0, nSeason*nSites*n_vis), ncol=(nSeason*n_vis),
dimnames=list(paste("site", 1:nSites, sep=""), paste("Season", 
rep(1:nSeason, each=n_vis), "v", 1:n_vis, sep="")))
obsocc <- as.data.frame(obsocc)

### simulate seasonal effects on local survival phi and phiC (for models
### testing the effect of including (right)/not including (wrong) seasonal
### effects on extinction colonization) using an additive term on the logit
### scale drawn from N(0,sd.s)  NOT USED
#logit.phi.meanI <- qlogis(phi_meanI)
#logit.phi.meanC <- qlogis(phi_meanC)
#s.effect <- rnorm((nyear-1), 0, sd.s)
#phiI <- plogis(logit.phi.meanI + s.effect)
#phiC <- plogis(logit.phi.meanC + s.effect)

###	Simulate tocc and obsocc from t = 1 to t = nyear
###	First use the Control paramater values for all sites
for(i in 1:nSites) {
tocc[i,1] = rbinom(1, 1, psi1)      
obsocc[i,1:n_vis] = rbinom(n_vis, 1, tocc[i,1]*p)  

for(t in 2:nSeason) {
if (tocc[i,t-1] == 1) {                   
tocc[i,t] <- rbinom(1,1,phi_meanC)
    		} else {
			tocc[i,t] <- rbinom(1,1,rC)
    		}
		for(j in 1:n_vis) {
			obsocc[i,((t-1)*n_vis)+j] <- rbinom(1,1,tocc[i,t]*p) 
		}
  	}
}

### Then simulate the Impact of the experimental treatment on local survival 
### in the Impact subset of matrices tocc and obsocc (i.e., treatment sites during the
### After period
for(i in 1:siteT) {
for(tt in (SeasonB+1):nSeason) {
    		if (tocc[i,tt-1] == 1) {
      			tocc[i,tt] <- rbinom(1,1,phi_meanI)
    		} else {
tocc[i,tt] <- rbinom(1,1,rI)
    		}
		for(j in 1:n_vis) {
			obsocc[i,((tt-1)*n_vis)+j] <- rbinom(1,1,tocc[i,tt]*p)
		}
  	}
}

### Creste site-specific covariate SiteTreat (Control / Impact)
obsocc$SiteTreat <- factor(c(rep('IMPACT', siteT), rep('CONTROL', nSites-siteT)))

### Create the matrix of seasonal site covariates SeasonBA. 
### IMPORTANT ###: Occupancy at t = 1 is psi1, so there are (nSeason1)
### transitions between seasons for modeling colonization and extinction 
### The function colext (Fiske and Chandler 2011) requires the full set of
### parameters (nSeason), but the last column of the matrix is unnecessary
### for modeling colonization and extinction. Therefore we fill the last
### column (i.e., last season) with the attribute Null.

Season.Before <- matrix(rep("BEFORE", nSites*(SeasonB-1)), ncol=(SeasonB-1))
Season.After <- matrix(rep("AFTER", nSites*SeasonA), ncol=SeasonA)
Season.Null <- matrix(rep("Null", nSites*1), ncol=1)
SeasonBA <- cbind(Season.Before, Season.After, Season.Null)
SeasonBA <- as.data.frame(SeasonBA)
colnames(SeasonBA) <- paste("Season", rep(1:nSeason), sep="")

### Create the matrix of seasonal site covariates Season
### IMPORTANT ###: last column = Null; see description for SeasonBA
Season <- matrix(rep(seq(1:(nSeason-1)), nSites), ncol=nSeason-1, byrow=T,
dimnames=list(paste("site", 1:nSites, sep=""), paste("Season", 
rep(1:(nSeason-1)), sep="")))
Season.Null <- matrix(rep("Null", nSites*1), ncol=1)
Season <- cbind(Season, Season.Null)
colnames(Season) <- paste("Season", rep(1:nSeason), sep="")
Season <- as.data.frame(Season)
Season <- data.frame(lapply(Season, as.factor))

### Create the matrix for SeasonSiteTreat; this covariate represents the
### interaction between Before/After and Control/Impact
### IMPORTANT ###: last column = Null; see description for SeasonBA
Before <- matrix(rep("CONTROL", nSites*(SeasonB-1)), ncol=(SeasonB-1))
AfterI <- matrix(rep("IMPACT", siteT*SeasonA), ncol=SeasonA)
AfterC <- matrix(rep("CONTROL", (nSites-siteT)*SeasonA), ncol=SeasonA)
Col.Null <- matrix(rep("Null", nSites*1), ncol=1)
SeasonSiteTreat <- cbind(Before, rbind(AfterT, AfterC), Col.Null)
SeasonSiteTreat <- as.data.frame(SeasonSiteTreat)
colnames(SeasonSiteTreat) <- paste("Season", rep(1:nSeason), sep="")

### Combine the observed P/A data and seasonal site covariates
obsocc <- cbind(obsocc, Season, SeasonBA, SeasonSiteTreat)

### Return observed territory occupancy matrix, i.e. the observations
return(data.frame(obsocc))

}